package com.phm.manage.service.impl;

import com.phm.manage.domain.AnalyzeDownLog;
import com.phm.manage.mapper.AnalyzeDownLogMapper;
import com.phm.manage.service.IAnalyzeDownLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 数据解析下载日志Service业务层处理
 *
 * @author phm
 * @date 2023-08-22
 */
@Service
public class AnalyzeDownLogServiceImpl implements IAnalyzeDownLogService {
    @Autowired
    private AnalyzeDownLogMapper analyzeDownLogMapper;

    /**
     * 查询数据解析下载日志
     *
     * @param id 数据解析下载日志主键
     * @return 数据解析下载日志
     */
    @Override
    public AnalyzeDownLog selectAnalyzeDownLogById(Long id) {
        return analyzeDownLogMapper.selectAnalyzeDownLogById(id);
    }

    /**
     * 查询数据解析下载日志列表
     *
     * @param analyzeDownLog 数据解析下载日志
     * @return 数据解析下载日志
     */
    @Override
    public List<AnalyzeDownLog> selectAnalyzeDownLogList(AnalyzeDownLog analyzeDownLog) {
        return analyzeDownLogMapper.selectAnalyzeDownLogList(analyzeDownLog);
    }

    /**
     * 新增数据解析下载日志
     *
     * @param analyzeDownLog 数据解析下载日志
     * @return 结果
     */
    @Override
    public int insertAnalyzeDownLog(AnalyzeDownLog analyzeDownLog) {
        return analyzeDownLogMapper.insertAnalyzeDownLog(analyzeDownLog);
    }

    /**
     * 修改数据解析下载日志
     *
     * @param analyzeDownLog 数据解析下载日志
     * @return 结果
     */
    @Override
    public int updateAnalyzeDownLog(AnalyzeDownLog analyzeDownLog) {
        return analyzeDownLogMapper.updateAnalyzeDownLog(analyzeDownLog);
    }

    /**
     * 批量删除数据解析下载日志
     *
     * @param ids 需要删除的数据解析下载日志主键
     * @return 结果
     */
    @Override
    public int deleteAnalyzeDownLogByIds(Long[] ids) {
        return analyzeDownLogMapper.deleteAnalyzeDownLogByIds(ids);
    }

    /**
     * 删除数据解析下载日志信息
     *
     * @param id 数据解析下载日志主键
     * @return 结果
     */
    @Override
    public int deleteAnalyzeDownLogById(Long id) {
        return analyzeDownLogMapper.deleteAnalyzeDownLogById(id);
    }
}
